/*
    futebus - FUse TExt BUS - fuse based IPC bus for text lines
    Copyright (C) 2023  Tibor 'Igor2' Palinkas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

    Project page: http://www.repo.hu/projects/futebus
    VCS: svn://svn.repo.hu/futebus/trunk
    Contact: see doc/contact.html
*/

#include <pthread.h>
#include <semaphore.h>

typedef pthread_mutex_t mutex_t;

static inline int mutex_init(mutex_t *mutex)     { return pthread_mutex_init(mutex, NULL); }
static inline int mutex_lock(mutex_t *mutex)     { return pthread_mutex_lock(mutex); }
static inline int mutex_unlock(mutex_t *mutex)   { return pthread_mutex_unlock(mutex); }
static inline int mutex_uninit(mutex_t *mutex)   { return pthread_mutex_destroy(mutex); }

typedef sem_t notify_t;
static inline int notify_init(notify_t *nt)      { return sem_init(nt, 0, 0); }
static inline int notify_send(notify_t *nt)      { return sem_post(nt); }
static inline int notify_uninit(notify_t *nt)    { return sem_destroy(nt); }

static inline int notify_wait_timed(notify_t *nt, const struct timespec *abs_to)
{
	return sem_timedwait(nt, abs_to);
}
